#!/usr/bin/env python
# -*- coding: utf-8 -*-
# -*- Python -*-

"""
 @file kinectMongoInsert.py
 @brief ModuleDescription
 @date $Date$


"""
import sys
import time
sys.path.append(".")

# Import RTM module
import RTC
import OpenRTM_aist
import pymongo
import numpy as np
from datetime import datetime

# Import Service implementation class
# <rtc-template block="service_impl">

# </rtc-template>

# Import Service stub modules
# <rtc-template block="consumer_import">
# </rtc-template>


# This module's spesification
# <rtc-template block="module_spec">
kinectmongoinsert_spec = ["implementation_id", "kinectMongoInsert", 
		 "type_name",         "kinectMongoInsert", 
		 "description",       "ModuleDescription", 
		 "version",           "1.1.2", 
		 "vendor",            "University of Aizu", 
		 "category",          "Category", 
		 "activity_type",     "STATIC", 
		 "max_instance",      "1", 
		 "language",          "Python", 
		 "lang_type",         "SCRIPT",
		"conf.default.collection_name", "kinect_collection",
		"conf.default.db_IP", "localhost",
		"conf.default.db_Port", "27017",

		"conf.__widget__.collection_name", "text",
		"conf.__widget__.db_IP", "text",
		"conf.__widget__.db_Port", "text",

		"conf.__type__.collection_name", "string",
		"conf.__type__.db_IP", "string",
		"conf.__type__db_Port", "int",

		 ""]
# </rtc-template>

##
# @class kinectMongoInsert
# @brief ModuleDescription
# 
# 
class kinectMongoInsert(OpenRTM_aist.DataFlowComponentBase):
	
	##
	# @brief constructor
	# @param manager Maneger Object
	# 
	def __init__(self, manager):
		OpenRTM_aist.DataFlowComponentBase.__init__(self, manager)

		self._d_skeleton = RTC.TimedFloatSeq(RTC.Time(0,0),[])
		"""
		"""
		self._skeletonIn = OpenRTM_aist.InPort("skeleton", self._d_skeleton)
		self._collection_name = ['kinect_collection']
		self._db_IP = ['localhost']
		self._db_Port = [27017]

	def onInitialize(self):
		# Bind variables and configuration variable
		self.bindParameter("collection_name", self._collection_name, "kinect_collection")
		self.bindParameter("db_IP", self._db_IP, "localhost")
		self.bindParameter("db_Port", self._db_Port, "27017")
		# Set InPort buffers
		self.addInPort("skeleton",self._skeletonIn)
		
		# Set OutPort buffers
		
		# Set service provider to Ports
		
		# Set service consumers to Ports
		
		# Set CORBA Service Ports
		
		return RTC.RTC_OK
	
	def onActivated(self, ec_id):
		self.client = pymongo.MongoClient(self._db_IP[0], self._db_Port[0])
		self.db = self.client[self._db_name[0]]
		self.co = self.db[self._collection_name[0]]	
		return RTC.RTC_OK
	
	def onExecute(self, ec_id):
		isDataIn = False
		kv = dict()
		dt = datetime.now()
		
		kv.setdefault("systemTIme", dt.strftime("%Y/%m/%d %H:%S.%.f"))
		if self._skeletonIn.isNew():
			isDataIn = True
			print(self._skeletonIn.read())
			kv.setdefault("skeleton", toMongTimedFloatSeq(self._skeletonIn.read()))
		if isDataIn:
			print(self._skeletonIn.raed())
			print(kv)
			self.co.insert_one(kv)
		return RTC.RTC_OK
	
def toMongTimedFloatSeq(dt):
	kv = {"time": [dt.tm.sec, dt.tm.nsec], "floatSeq":dt.data}
	return kv
def kinectMongoInsertInit(manager):
    profile = OpenRTM_aist.Properties(defaults_str=kinectmongoinsert_spec)
    manager.registerFactory(profile,
                            kinectMongoInsert,
                            OpenRTM_aist.Delete)

def MyModuleInit(manager):
    kinectMongoInsertInit(manager)

    # Create a component
    comp = manager.createComponent("kinectMongoInsert")

def main():
	mgr = OpenRTM_aist.Manager.init(sys.argv)
	mgr.setModuleInitProc(MyModuleInit)
	mgr.activateManager()
	mgr.runManager()

if __name__ == "__main__":
	main()

